# -*- coding: utf-8 -*-

"""
application init
"""

default_app_config: str = "timezones.apps.AaTimezonesConfig"

__version__ = "1.2.1"
__title__ = "Time Zones"
